#
# spec file for package rust-srpm-macros
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017 Red Hat, Inc., Raleigh, North Carolina, United States of America.
# Copyright (c) 2017, 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org>.
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rust-srpm-macros
Version:        15
Release:        bp156.3.1
Summary:        RPM macros for building Rust source packages
License:        MIT
Group:          Development/Languages/Rust
URL:            https://pagure.io/fedora-rust/rust2rpm
Source0:        https://releases.pagure.org/fedora-rust/rust2rpm/rust2rpm-%{version}.tar.xz

# Backports from upstream
Patch0001:      0001-Add-riscv64-to-rust_arches.patch

BuildArch:      noarch

%description
This package provides the RPM macros for building usable Source RPMs
of Rust packages.

%prep
%autosetup -n rust2rpm-%{version} -p1

# Target arch is i586 on these distributions
sed -e "s/i686/i586 i686/" -i data/macros.rust-srpm
# Work around bugs in ppc64* arch setup in SUSE rpm
sed -e "s/ppc64 ppc64le/ppc64 powerpc64 ppc64le powerpc64le/" -i data/macros.rust-srpm
# Add armv6hl to supported arches
sed -e "s/armv7hl/armv6hl armv7hl/" -i data/macros.rust-srpm

%install
install -D -p -m 0644 -t %{buildroot}%{_rpmconfigdir}/macros.d data/macros.rust-srpm

%files
%license LICENSE
%{_rpmconfigdir}/macros.d/macros.rust-srpm

%changelog
* Thu Aug 13 2020 Neal Gompa <ngompa13@gmail.com>
- Backport patch to add 64-bit RISC-V support
  + Patch: 0001-Add-riscv64-to-rust_arches.patch
* Fri May 22 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 15
  + metadata: Fix setting up tilde version in RPM
  + templates: Generate files entry with no-tilde
  + inspector: Add support for multiple features
  + metadata: Support "renamed" dependencies
  + Use `cargo install --no-track` with cargo 1.41
  + metadata: support versions like X.*.*
  + Fix up Cargo.toml.orig error message that started to appear with Rust 1.43.0
* Wed Dec  4 2019 Igor Gnatenko <i.gnatenko.brain@gmail.com>
- Update to 11
* Thu Aug 29 2019 Thomas Bechtold <tbechtold@suse.com>
- update to version 10
  * Translate '-or-later' and '+' license suffixes properly
  * Check /usr/lib/os-release in addition to /etc/os-release
  * Prettify summary and description automatically
  * Use %%{expand:…} for %%description to avoid escaping of newlines
  * Add '--suffix' option for "compat" packages
  * Implement option to skip building of crates (aka fast/bootstrap build)
* Sun May  5 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 9
  + Remove temporary Cargo.toml.deps
  + Fix packager identity detection to use fallbacks properly
  + Always put upstream license data comment in generated specs
* Tue Apr 23 2019 Igor Gnatenko <i.gnatenko.brain@gmail.com>
- Update to version 8
  * Pass `-Ccodegen-units=1` in RUSTFLAGS
  * Switch to `%%{build_rustflags}`
- Changes since version 6
  * Fix `%%cargo_install` with crates which use whitespace in files
- Drop patches part of this release
  * 0001-name-spec-patch_file-by-real-crate-name.patch
  * 0002-generate-doc-statements.patch
  * 0003-do-better-for-renamed-crates.patch
  * 0004-remove-pre-3.6-leftovers.patch
  * 0005-Remove-half-downloaded-crate-on-C.patch
  * 0006-Throw-an-error-if-s-is-used-without-a-crate.patch
  * 0007-split-features-into-subpackages.patch
  * 0008-add-support-for-dependencies-with-same-name.patch
  * 0009-add-support-for-feeding-user-configuration.patch
  * 0010-trivial-use-f-strings-everywhere.patch
  * 0011-Add-option-to-not-generate-a-default-changelog-entry.patch
  * 0012-Set-CARGO_HOME-to-the-local-.config.patch
  * 0013-Set-the-install-root-in-.cargo-config.patch
  * 0014-Add-support-for-prerelease-versions.patch
* Tue Mar  5 2019 Igor Gnatenko <i.gnatenko.brain@gmail.com>
- Backport upstream patch for tilde handling
* Sun Nov 11 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 6
  + pass %%__cargo_common_opts to %%cargo_install
  + make %%cargo_* macros parametric
  + remove support for target-dir
* Sun Jan 21 2018 Neal Gompa <ngompa13@gmail.com>
- Flesh out the descriptions of the produced binary packages
* Sat Jan 20 2018 Neal Gompa <ngompa13@gmail.com>
- Add armv6hl to supported arches
* Sat Jan 20 2018 Neal Gompa <ngompa13@gmail.com>
- Work around bugs in ppc64* arch setup in SUSE rpm
* Sat Jan 13 2018 Neal Gompa <ngompa13@gmail.com>
- Initial packaging for (open)SUSE
* Mon Jan  8 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org>
- Update to 5
* Sat Jul  8 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org>
- Include license
* Fri Jul  7 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org>
- Update to 4
* Tue Jun 13 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org>
- Initial package
